@@ -31,6 +31,30 @@ sub distribution {
     return $self->{distribution};
 }
 
+sub meta_merge {
+    return {
+	'meta-spec'	=> {
+	    version	=> 2,
+	},
+	dynamic_config	=> 1,
+	no_index	=> {
+	    directory	=> [ qw{ inc t tools xt } ],
+	},
+	resources	=> {
+	    bugtracker	=> {
+                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack',
+                mailto  => 'wyant@cpan.org',
+            },
+	    license	=> 'http://dev.perl.org/licenses/',
+	    repository	=> {
+		type	=> 'git',
+		url	=> 'git://github.com/trwyant/perl-Astro-SpaceTrack.git',
+		web	=> 'https://github.com/trwyant/perl-Astro-SpaceTrack',
+	    },
+	}
+    };
+}
+
 sub notice {
     my ( $self, $opt, $prompter ) = @_;
 
@@ -65,7 +89,6 @@ sub requires {
     my ( $self, @extra ) = @_;
 
     return {
-	'Archive::Zip'		=> 0,		# For mccants().
 	'Carp'			=> 0,
 	'Data::Dumper'		=> 0,
 	'Exporter'		=> 0,
@@ -75,10 +98,17 @@ sub requires {
 	'HTTP::Response'	=> 0,
 	'HTTP::Status'		=> 6.03,	# For the teapot status
 	'IO::File'		=> 0,
+	'IO::Uncompress::Unzip'	=> 0,	# For McCants
 	'JSON'			=> 0,	# For Space Track v2
 	'List::Util'		=> 0,	# For Space Track v2 FILE tracking
 	'LWP::UserAgent'	=> 0,
 	'LWP::Protocol::https'	=> 0,	# Space track needs as of 11-Apr-2011
+	'Mozilla::CA'		=> 20141217,
+					# There is no direct dependency
+					# on this, but some CPAN testers
+					# consistently fail with CERT
+					# problems, and I know this
+					# works.
 	'POSIX'			=> 0,
 	'Scalar::Util'		=> 1.07,	# for openhandle.
 	'Text::ParseWords'	=> 0,
@@ -152,6 +182,16 @@ C<< {META_MERGE}->{build_requires} >> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 meta_merge
+
+ use YAML;
+ print Dump( $meta->meta_merge() );
+
+This method returns a reference to a hash describing the meta-data which
+has to be provided by making use of the builder's C<meta_merge>
+functionality. This includes the C<dynamic_config>, C<no_index> and
+C<resources> data.
+
 =head2 notice
 
  my @exes = $meta->notice( \%opt, \&prompter );
@@ -214,7 +254,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2014 by Thomas R. Wyant, III
+Copyright (C) 2010-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
